summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp b/kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp
index 1041fb9c..64879548 100644
--- a/kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/coreprotocol.cpp
@@ -5,7 +5,7 @@
Copyright (c) 2004 SUSE Linux AG http://www.suse.com
Based on Iris, Copyright (C) 2003 Justin Karneges
- url_escape_string from Gaim src/protocols/novell/nmconn.c
+ url_escape_string from Pidgin src/protocols/novell/nmconn.c
Copyright (c) 2004 Novell, Inc. All Rights Reserved
Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
@@ -273,11 +273,11 @@ void CoreProtocol::fieldsToWire( Field::FieldList fields, int depth )
TQDataStream dout( bytesOut, IO_WriteOnly );
dout.setByteOrder( TQDataStream::LittleEndian );
// these fields are ignored by Gaim's novell
if ( field->type() == NMFIELD_TYPE_BINARY || field->method() == NMFIELD_METHOD_IGNORE )
continue;
// GAIM writes these tags to the secure socket separately - if we can't connect, check here
// NM Protocol 1 writes them in an apparently arbitrary order
// tag
//dout.writeRawBytes( GW_URLVAR_TAG, sizeof( GW_URLVAR_TAG ) );
@@ -273,11 +273,11 @@ void CoreProtocol::fieldsToWire( Field::FieldList fields, int depth )
TQDataStream dout( bytesOut, IO_WriteOnly );
dout.setByteOrder( TQDataStream::LittleEndian );
- // these fields are ignored by Gaim's novell
+ // these fields are ignored by Pidgin's novell
if ( field->type() == NMFIELD_TYPE_BINARY || field->method() == NMFIELD_METHOD_IGNORE )
continue;
@@ -273,11 +273,11 @@ void CoreProtocol::fieldsToWire( Field::FieldList fields, int depth )
if ( field->type() == NMFIELD_TYPE_BINARY || field->method() == NMFIELD_METHOD_IGNORE )
continue;
- // GAIM writes these tags to the secure socket separately - if we can't connect, check here
+ // PIDGIN writes these tags to the secure socket separately - if we can't connect, check here
// NM Protocol 1 writes them in an apparently arbitrary order
// tag